@@ -1,16 +1,15 @@
 #!/usr/bin/perl -d:DProf
 
-use lib 'lib', '../lib';
+use lib 'lib', '../lib';	
 use Exception::Base ':all',
     'Exception::System';
 
-
 my $n = 0;
 
 foreach (1..10000) {
-    try eval { throw Exception::System message=>'Message'; };
+    try eval { Exception::System->throw(message=>'Message') };
     if (catch my $e) {
-        if ($e->isa('Exception') and $e->with('Message')) { $n++; }
+        if ($e->isa('Exception::System') and $e->with('Message')) { $n++; }
     }
 }
 
